EventReceiver

Struct EventReceiver 

pub struct EventReceiver { /* private fields */ }
Receiver for events from the event bus.

Implementations

Source

impl EventReceiver

pub fn drain_lagged(&mut self) -> u64

Returns and resets the cumulative count of messages lost due to broadcast channel lag since the last call.

pub async fn recv(&mut self) -> Option<Arc<AstridEvent>>

Receive the next event.

Returns None if the channel is closed or if events were dropped due to the receiver being too slow.

pub fn try_recv(&mut self) -> Option<Arc<AstridEvent>>

Try to receive the next event without blocking.

Returns Some(event) if an event is available, or None if no event is available or the channel is closed.